@@ -7,23 +7,25 @@
  */
 
 #include <Akonadi/Collection>
+using namespace Qt::Literals::StringLiterals;
+
 #include <QDir>
 #include <QTest>
 
+#include "../search/calendar/calendarsearchstore.h"
+#include "../search/contact/contactsearchstore.h"
+#include "../search/email/emailsearchstore.h"
 #include "calendarindexer.h"
 #include "contactindexer.h"
 #include "emailindexer.h"
-#include <../search/calendar/calendarsearchstore.h>
-#include <../search/contact/contactsearchstore.h>
-#include <../search/email/emailsearchstore.h>
-#include <query.h>
+#include "query.h"
 
 Q_DECLARE_METATYPE(QSet<qint64>)
 Q_DECLARE_METATYPE(QList<qint64>)
 
 KMime::Message::Ptr readMailFromFile(const QString &mailFile)
 {
-    QFile file(QLatin1String(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
+    QFile file(QLatin1StringView(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
     file.open(QIODevice::ReadOnly);
     Q_ASSERT(file.isOpen());
     auto mailData = KMime::CRLFtoLF(file.readAll());
@@ -69,9 +71,9 @@ private:
 private Q_SLOTS:
     void init()
     {
-        emailDir = QDir::tempPath() + QLatin1String("/searchplugintest/email/");
-        emailContactsDir = QDir::tempPath() + QLatin1String("/searchplugintest/emailcontacts/");
-        contactsDir = QDir::tempPath() + QLatin1String("/searchplugintest/contacts/");
+        emailDir = QDir::tempPath() + "/searchplugintest/email/"_L1;
+        emailContactsDir = QDir::tempPath() + "/searchplugintest/emailcontacts/"_L1;
+        contactsDir = QDir::tempPath() + "/searchplugintest/contacts/"_L1;
         notesDir = QDir::tempPath() + QStringLiteral("/searchplugintest/notes/");
         calendarsDir = QDir::tempPath() + QStringLiteral("/searchplugintest/calendars/");
 
