@@ -75,11 +75,7 @@ Xapian::Query PIMSearchStore::constructQuery(const QString &property, const QVar
         if (value.isNull()) {
             isTrue = true;
         }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if (value.type() == QVariant::Bool) {
-#else
         if (value.userType() == QMetaType::Bool) {
-#endif
             isTrue = value.toBool();
         }
 
@@ -143,3 +139,5 @@ QUrl PIMSearchStore::constructUrl(const Xapian::docid &docid)
 
     return url;
 }
+
+#include "moc_pimsearchstore.cpp"
