@@ -55,7 +55,7 @@ QStringList XapianTermGenerator::termList(const QString &text)
             QString cleanString;
             cleanString.reserve(denormalized.size());
             for (const QChar &ch : denormalized) {
-                auto cat = ch.category();
+                const auto cat = ch.category();
                 if (cat != QChar::Mark_NonSpacing && cat != QChar::Mark_SpacingCombining && cat != QChar::Mark_Enclosing) {
                     cleanString.append(ch);
                 }
